.. Wallaroo SDK documentation master file, created by
   sphinx-quickstart on Thu Jun 17 16:06:42 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Wallaroo
========

Take your boldest algorithms live against production data faster, simpler, and at far lower cost.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview
   single-sign-on
   models.ipynb
   core-abstractions.ipynb
   experiments.ipynb
   monitoring.ipynb
   model-insights.ipynb
   python-processing.ipynb
   standalone-mode.ipynb
   workspaces.ipynb
   autoscaling.ipynb
   sdk
   jupyter


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
